==> nodegit-0.2.4.tgz: package/src/note_iterator.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/note_iterator.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitNoteIterator::GitNoteIterator(git_note_iterator *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitNoteIterator::~GitNoteIterator() {
   }

  void GitNoteIterator::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(New);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("NoteIterator"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("NoteIterator"), _constructor_template);
  }

  NAN_METHOD(GitNoteIterator::New) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitNoteIterator cannot be instantiated.");
     }

    GitNoteIterator* object = new GitNoteIterator(static_cast<git_note_iterator *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitNoteIterator::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitNoteIterator::constructor_template)->NewInstance(2, argv));
  }

  git_note_iterator *GitNoteIterator::GetValue() {
    return this->raw;
  }

  git_note_iterator **GitNoteIterator::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitNoteIterator::constructor_template;

==> nodegit-0.2.5.tgz: package/src/note_iterator.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/note_iterator.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitNoteIterator::GitNoteIterator(git_note_iterator *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitNoteIterator::~GitNoteIterator() {
   }

  void GitNoteIterator::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(JSNewFunction);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("NoteIterator"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("NoteIterator"), _constructor_template);
  }

  NAN_METHOD(GitNoteIterator::JSNewFunction) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitNoteIterator cannot be instantiated.");
     }

    GitNoteIterator* object = new GitNoteIterator(static_cast<git_note_iterator *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitNoteIterator::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitNoteIterator::constructor_template)->NewInstance(2, argv));
  }

  git_note_iterator *GitNoteIterator::GetValue() {
    return this->raw;
  }

  git_note_iterator **GitNoteIterator::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitNoteIterator::constructor_template;
